<!--
SPDX-FileCopyrightText: 2023 The dune-iga developers mueller@ibb.uni-stuttgart.de
SPDX-License-Identifier: LGPL-3.0-or-later
-->

# Master (becomes Release vx.x)
- Added basic trimming functionality (#7) with henrij22 very nice work!
